==> apache-camel-2.16.4-src.zip: apache-camel-2.16.4/components/camel-twitter/src/main/java/org/apache/camel/component/twitter/consumer/TwitterConsumerEvent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.twitter.consumer;

import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.component.twitter.TwitterEndpoint;
import org.apache.camel.component.twitter.consumer.streaming.StreamingConsumer;
import org.apache.camel.impl.DefaultConsumer;
import twitter4j.Status;

public class TwitterConsumerEvent extends DefaultConsumer implements TweeterStatusListener {
    private Twitter4JConsumer twitter4jConsumer;

    public TwitterConsumerEvent(TwitterEndpoint endpoint, Processor processor,
                                Twitter4JConsumer twitter4jConsumer) {
        super(endpoint, processor);
        this.twitter4jConsumer = twitter4jConsumer;
    }

    @Override
    protected void doStart() throws Exception {
        super.doStart();
        if (twitter4jConsumer instanceof StreamingConsumer) {
            ((StreamingConsumer) twitter4jConsumer).registerTweetListener(this);
            ((StreamingConsumer) twitter4jConsumer).doStart();
        }
    }

    @Override
    protected void doStop() throws Exception {
        super.doStop();
        if (twitter4jConsumer instanceof StreamingConsumer) {
            ((StreamingConsumer) twitter4jConsumer).unregisterTweetListener(this);
            ((StreamingConsumer) twitter4jConsumer).doStop();
        }
    }

    @Override
    public void onStatus(Status status) {
        Exchange exchange = getEndpoint().createExchange();
        exchange.getIn().setBody(status);

        try {
            getProcessor().process(exchange);
        } catch (Exception e) {
            exchange.setException(e);
        }

        if (exchange.getException() != null) {
            getExceptionHandler().handleException("Error processing exchange on status update", exchange, exchange.getException());
        }
    }
}

==> apache-camel-2.18.5-src.zip: apache-camel-2.18.5/components/camel-twitter/src/main/java/org/apache/camel/component/twitter/consumer/TwitterConsumerEvent.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.twitter.consumer;

import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.component.twitter.TwitterEndpoint;
import org.apache.camel.component.twitter.consumer.streaming.AbstractStreamingConsumer;
import org.apache.camel.impl.DefaultConsumer;

public class TwitterConsumerEvent extends DefaultConsumer implements TwitterEventListener {
    private final TwitterConsumer twitter4jConsumer;

    public TwitterConsumerEvent(TwitterEndpoint endpoint, Processor processor, TwitterConsumer twitter4jConsumer) {
        super(endpoint, processor);
        this.twitter4jConsumer = twitter4jConsumer;
    }

    @Override
    protected void doStart() throws Exception {
        super.doStart();

        if (twitter4jConsumer instanceof AbstractStreamingConsumer) {
            ((AbstractStreamingConsumer) twitter4jConsumer).setEventListener(this);
            ((AbstractStreamingConsumer) twitter4jConsumer).start();
        }
    }

    @Override
    protected void doStop() throws Exception {
        if (twitter4jConsumer instanceof AbstractStreamingConsumer) {
            ((AbstractStreamingConsumer) twitter4jConsumer).removeEventListener(this);
            ((AbstractStreamingConsumer) twitter4jConsumer).stop();
        }

        super.doStop();
    }

    @Override
    public void onEvent(Exchange exchange) {
        if (!isRunAllowed()) {
            return;
        }

        try {
            getProcessor().process(exchange);
        } catch (Exception e) {
            exchange.setException(e);
        }

        if (exchange.getException() != null) {
            getExceptionHandler().handleException("Error processing exchange on status update", exchange, exchange.getException());
        }
    }
}
